История изменений
=================

0.3x
-----

0.3.0
~~~~~

* Удалена поддержка ``Python 2.6``
* Добавлена поддержка ``Python 3.5``
* Удалена поддержка ``Django`` версий ``1.5`` и ``1.6``
* Расширенная документация на `Read the Docs <https://readthedocs.org/>`_
* Добавлена поддержка ``Django 1.9``. Спасибо за помощь `Максиму Оранскому <https://github.com/sdfsdhgjkbmnmxc>`_, PR #27
* Исправлена ошибка ``urllib.unquote`` в Py3 (спасибо `mcd-php <https://github.com/mcd-php>`_)
* Дефолтное имя (UUID) обрезано до 30 символов для совместимости с длиной поля username по умолчанию. Спасибо `Haos616 <https://github.com/Haos616>`_)
* Исправлена ошибка при обращении к urllib.unquote в Python 3.x. Исправил `mcd-php <https://github.com/mcd-php>`_, PR #32
* Исправлена ошибка, приводящая к UnicodeDecodeError при использовании Python 3.x. Исправил `mcd-php <https://github.com/mcd-php>`_, PR #33
* Исправлены бейджи


0.2x
----

0.2.3
~~~~~

* Обновлена HEAD-версия Django

0.2.2
~~~~~

* Обновлена HEAD-версия Django

0.2.1
~~~~~

* Удалена поддержка ``python 3.2``, добавлена поддержка ``3.4``
* Улучшен ``PEP-0008``
* Добавлен ``coverage``

0.1x
----

0.1.9
~~~~~

* Добавлена обработка подтверждения почты (параметр ``verify=1``, см. http://ulogin.ru/help.php#faq)

0.1.8
~~~~~

+ Добавлены провайдеры ``Google+``, ``Foursquare``, ``Tumblr``, ``Dudu``;
* Отказ от поддержки ``Django 1.4x`` и ниже;
* Улучшение кода по ``PEP-0008``
* Изменение кода виджета
* Поддержка собственной модели пользователя ``Django``
* Обновлён демонстрационный проект

0.1.7
~~~~~

* Исправена ошибка, связанная с декодированием uri, в котором встречаются не ascii-символы (исправил `mike-grayhat <https://github.com/mike-grayhat>`_)

0.1.6
~~~~~

* Добавлен параметр ``ULOGIN_AUTHENTICATION_BACKEND``
* Грамотная работа с timezones при ``USE_TZ=True`` (в Django 1.4)

0.1.5
~~~~~

* Отказ от поддержки ``Django 1.2x``
* использованы class based views.
* Можно входить в свой аккаунт через различных провайдеров.
* Можно отвязывать аккаунты в соц. сетях от своего пользователя
* Новое поле: ``phone``
* Новые провайдеры: 
  * ``flickr``
  * ``vimeo`` 
  * ``webmoney``
  * ``youtube`` 
  * ``steam``
  * ``soundcloud`` 
  * ``lastfm``
  * ``linkedin``
  * ``liveid``
* ``JS`` виджета подключается по ``HTTP`` или ``HTTPS`` в зависимости от того, какой схемой пользуется посетитель
* Исправлены неточности в документации (добавлено про обязательные контекст-процессоры)
* Соответствие ``pep-0008`` :)

0.1.4
~~~~~

* Добавлена поддержка схем виджетов (позволяет разместить на одной странице несколько разных виджетов)
* Обновлена документация
* Изменён HTML-код в соотстветствии с требованиями ``ulogin``
